==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/bibtexstring.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXSTRING_H
#define BIBTEXSTRING_H

#include <bibtexelement.h>

class QString;

class BibTeXString : public BibTeXElement
{
    Q_OBJECT
public:
    BibTeXString( const QString &key, const QString &value, QObject *parent = 0, const char *name = 0 );
    BibTeXString( BibTeXString *other );
    ~BibTeXString();

    void setKey( const QString &key );
    QString key();
    void setValue( const QString &value );
    QString value();

    QString toString( BibTeXFile::Format format = BibTeXFile::formatBibTeX, BibTeXFile::Encoding encoding = BibTeXFile::encImplicit );
    bool containsPattern( const QString& pattern, bool caseSensitive = false );

private:
    QString m_key;
    QString m_value;
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexstring.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXSTRING_H
#define BIBTEXSTRING_H

#include <bibtexelement.h>

class QString;

namespace BibTeX
{

    class BibTeXString : public BibTeXElement
    {
    public:
        BibTeXString( const QString &key );
        BibTeXString( BibTeXString *other );
        virtual ~BibTeXString();

        void setKey( const QString &key );
        QString key();

        void appendStringItem( const BibTeXElement::FieldItem& stringItem );
        void clearStringItems();
        BibTeXElement::FieldItems::iterator begin();
        BibTeXElement::FieldItems::iterator end();

        //         QString toString( BibTeXFile::Format format = BibTeXFile::formatBibTeX, BibTeXFile::Encoding encoding = BibTeXFile::encImplicit, BibTeXXSLTransform *xslt = NULL );
        bool containsPattern( const QString& pattern, bool caseSensitive = false );

    private:
        QString m_key;
        BibTeXElement::FieldItems m_stringItems;
    };

}

#endif
